#### This uses zip_code, latitude and longitude data from geonames and timezonefinder packages.
#### Convenience functions to get:
##### 1. The latitude and longitude for a given US or Puerto Rico Zip Code
##### 2. The more commonly identifiable timezone for a given zipcode(ex: Eastern, Central, Mountain, et al)

